Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2104)

Unified Diff: cc/layers/render_surface_impl.cc

Issue 2828353003: Determine mask UVs based on texture size (Closed)
Patch Set: Add tolerance to filter_effects.html Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/layers/layer.h ('k') | cc/layers/render_surface_impl_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/layers/render_surface_impl.cc
diff --git a/cc/layers/render_surface_impl.cc b/cc/layers/render_surface_impl.cc
index a03fb006fec237bdeac7d59bbdc6e1c5fab60977..3f0c66e45485777f31c083263a2c0703e4c1c4f5 100644
--- a/cc/layers/render_surface_impl.cc
+++ b/cc/layers/render_surface_impl.cc
@@ -417,14 +417,11 @@ void RenderSurfaceImpl::AppendQuads(RenderPass* render_pass,
return;
}
mask_layer->GetContentsResourceId(&mask_resource_id, &mask_texture_size);
- gfx::SizeF unclipped_mask_target_size = gfx::ScaleSize(
- gfx::SizeF(OwningEffectNode()->unscaled_mask_target_size),
- surface_contents_scale.x(), surface_contents_scale.y());
// Convert content_rect from target space to normalized space.
// Where unclipped_mask_target_size maps to gfx::Size(1, 1).
mask_uv_rect = gfx::ScaleRect(gfx::RectF(content_rect()),
- 1.0f / unclipped_mask_target_size.width(),
- 1.0f / unclipped_mask_target_size.height());
+ 1.0f / mask_texture_size.width(),
+ 1.0f / mask_texture_size.height());
}
gfx::RectF tex_coord_rect(gfx::Rect(content_rect().size()));
« no previous file with comments | « cc/layers/layer.h ('k') | cc/layers/render_surface_impl_unittest.cc » ('j') | no next file with comments »
@@ -417,14 +417,11 @@ void RenderSurfaceImpl::AppendQuads(RenderPass* render_pass,
// Convert content_rect from target space to normalized space.
- // Where unclipped_mask_target_size maps to gfx::Size(1, 1).
+ // Where mask_texture_size maps to gfx::Size(1, 1).
mask_uv_rect = gfx::ScaleRect(gfx::RectF(content_rect()),

Powered by Google App Engine
This is Rietveld 408576698